# PHRINGE

[![PyPI](https://img.shields.io/pypi/v/phringe.svg)][pypi_]

[//]: # ([![Status]&#40;https://img.shields.io/pypi/status/phringe.svg&#41;][status])
[![Python Version](https://img.shields.io/pypi/pyversions/phringe)][python version]
[![License](https://img.shields.io/pypi/l/phringe)][license]

[![Read the documentation at https://phringe.readthedocs.io/](https://img.shields.io/readthedocs/phringe/latest.svg?label=Read%20the%20Docs)][read the docs]

[//]: # ([![Tests]&#40;https://github.com/pahuber/phringe/workflows/Tests/badge.svg&#41;][tests])

[//]: # ([![Codecov]&#40;https://codecov.io/gh/pahuber/phringe/branch/main/graph/badge.svg&#41;][codecov])

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)][pre-commit]
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)][black]

[pypi_]: https://pypi.org/project/phringe/

[status]: https://pypi.org/project/phringe/

[python version]: https://pypi.org/project/phringe

[read the docs]: https://phringe.readthedocs.io/

[tests]: https://github.com/pahuber/phringe/actions?workflow=Tests

[codecov]: https://app.codecov.io/gh/pahuber/phringe

[pre-commit]: https://github.com/pre-commit/pre-commit

[black]: https://github.com/psf/black

<img src="docs/_static/phringe_logo.png" alt="Projekt-Logo" width="200"/>

<br>

**PHRINGE** is a **PH**otoelectron counts generato**R** for null**ING** int**E**rferometers and offers
fast Monte Carlo-based generation of synthetic data for space-based nulling interferometers observing exoplanetary
systems.

## Documentation

For installation instructions and examples please check out
the <a href="https://phringe.readthedocs.io/en/latest/" target="_blank">Readthedocs
Documentation</a>.

## Contributing

Contributions are very welcome.
To learn more, see the [Contributor Guide].

## License

Distributed under the terms of the [MIT license][license],
PHRINGE is free and open source software.

## Issues

If you encounter any problems,
please [file an issue] along with a detailed description.

## Credits

This project structure was generated from [@cjolowicz]'s [Hypermodern Python Cookiecutter] template.

[@cjolowicz]: https://github.com/cjolowicz

[pypi]: https://pypi.org/

[hypermodern python cookiecutter]: https://github.com/cjolowicz/cookiecutter-hypermodern-python

[file an issue]: https://github.com/pahuber/phringe/issues

[pip]: https://pip.pypa.io/

<!-- github-only -->

[license]: https://github.com/pahuber/phringe/blob/main/LICENSE

[contributor guide]: https://github.com/pahuber/phringe/blob/main/CONTRIBUTING.md

[command-line reference]: https://phringe.readthedocs.io/en/latest/usage.html
